import 'package:dio/dio.dart';
import 'package:stokkur_api_client/stokkur_api_client.dart';

class ApiClient {
  ApiClient._privateConstructor();
  static final ApiClient _instance = ApiClient._privateConstructor();

  late Dio dio;

  factory ApiClient({
    required String baseUrl,
    required Map<String, Object> headers,
    List<Interceptor>? interceptors,
  }) {
    _instance.dio = Dio(BaseOptions(
      baseUrl: baseUrl,
      headers: headers,
      connectTimeout: 5000,
      receiveTimeout: 3000,
    ));
    if (interceptors != null) {
      _instance.dio.interceptors.addAll(interceptors);
    }

    return _instance;
  }

  /// Helper method to handle the request response and errors
  Future<ApiResult<T>> request<T>(
    ApiRequest request,
    Function(dynamic) fromJson, {
    bool showGenericError = true,
  }) async {
    try {
      final response = await _instance.dio.request(
        request.url,
        data: request.body,
        queryParameters: request.query,
        options: Options(method: request.method, headers: request.headers),
      );
      return ApiResult.success(data: fromJson(response.data));
    } catch (e) {
      final exception = ApiException.getDioException(e);
      return ApiResult.failure(error: exception);
    }
  }

  Future<String?> requestUri(String uri, Dio httpClient) async {
    final response = await httpClient.requestUri(Uri.parse(uri));

    return response.data;
  }
}
